#!/bin/csh 
#########################################################################
# USAGE                                                                 #
#########################################################################
echo "Script to run Xell SPheRIO 4.0 on STAR PBS cluster"
if (($# < 1)||($# > 5)) then
cat << EOF
Usage:
  `basename $0` name_of_collision 
        [number_of_events] [first_event] [index_of_node] [starting_folder]
EOF
exit 1
endif
#########################################################################
# INPUT                                                                 #
#########################################################################
#set OBJ = "~/source/OBJ"
#set SPOVSN = "401"
set cnamecoll = $1
echo "Name of collisions is: " $cnamecoll
@ ievent_d = 1
if ($# >= 2) then
  @ ievent_d = $2
endif
echo "Number of events is: " $ievent_d
@ ievent_i = 1
if ($# >= 3) then
  @ ievent_i = $3
endif
echo "The first event number is: " $ievent_i
set cfolderindex = ""
if ($# >= 4) then
  set cfolderindex = $4
endif
echo "The work folder finger-print is: " $cfolderindex
@ ievent_f = $ievent_i + $ievent_d - 1
echo "The number of the last event to be run is: " $ievent_f
set EXEC = $OBJ/spherio$SPOVSN/Xellspherio
echo "Path and name of executable file is: " $EXEC
set starting_folder = `pwd`
if ($# >= 5) then
set starting_folder = $5
if (! -d $starting_folder) then
    echo "WARNING: " $starting_folder " does not exist!"
    exit 1
endif
endif
echo "Starting folder is: "$starting_folder
if ( -e $starting_folder/$cnamecoll.optns ) then
else
    echo $starting_folder/$cnamecoll.optns "does not exist"
exit
endif
set working_folder = $starting_folder$cfolderindex
if ($working_folder != $starting_folder) then
    echo "Working folder is: "$working_folder
    rm -rf $working_folder
    mkdir $working_folder
    cp -f $starting_folder/$cnamecoll.optns $working_folder/$cnamecoll.optns
    cp -f $starting_folder/$cnamecoll.spherio.optns $working_folder/$cnamecoll.spherio.optns
    cd $working_folder
endif
echo " "

#########################################################################
# EXECUTE                                                               #
#########################################################################
foreach ievent (`seq $ievent_i $ievent_f`)

set ceventname = $cnamecoll-$ievent

rm -f $CHK/z-$ceventname.check 
rm -f $CHK/z-$ceventname.data 
rm -f $CHK/z-$ceventname.copy 
rm -f $CHK/z-$ceventname.log
rm -f $CHK/z-$ceventname.mtr

if ( $OPT == '.' ) then 
    setenv odir `pwd`
else
    setenv odir $OPT
endif
echo "###################################################################"
echo "#               Welcome to Xell 1.0 SPheRIO 4.0                   #"      
echo "#     This is the entrance of" $ievent"-th event running on the node" $cfolderindex"    #"
echo "###################################################################"
setenv seedspo `date  '+%N'`
echo "spherio seed: " $seedspo

#---------------------------------------------------------------------
date
time $EXEC -n << EOF
!fname mtr    $CHK/z-$ceventname.mtr        !redirect screen output to mtr
!echo off
!----spherio----
beginoptns spherio
!uncomment the following line to get random seed for spherio
set seedspo   $seedspo
fname pathspo $SPO/                         !SPHERIO path
fname patheos $EOS/                         !EOS path
fname pathhto $HTO/                         !HTO path
fname cnome   $ceventname                   !collision name
fname ztr     $HTO/$ceventname.ztr.data     !ztr.data
fname nan     $HTO/$ceventname.nan.data     !nancatchup.data
fname flgfp   $HTO/$ceventname.flgfp.data   !flgfp.list.data
fname flgce   $HTO/$ceventname.flgce.data   !iflgce.err.data
fname chfz    $HTO/$ceventname.chfz.data    !setevg.chfz.data
fname soma    $HTO/$ceventname.soma.data    !setevg.soma.data
fname enda    $HTO/$ceventname.enda.data    !setevg.sphrenda.data
fname nsp     $HTO/$ceventname.nsp.data     !nsp.err.data
fname eos     $HTO/$ceventname.eos.data     !eosdebug.data
fname hbt     $HTO/$ceventname.hbt.data     !hbt.data
fname fzout   $HTO/$ceventname.fzo.data     !freeze-out info
fname xell    $HTO/zx-$ceventname.data      !xell.data
endoptns spherio
!----endspherio----
fname pathnx  $EPO/
fname ico     $HTO/$ceventname.ico
fname histo   $HTO/$ceventname.histo
fname check   $CHK/z-$ceventname.check
fname copy    $CHK/z-$ceventname.copy
fname log     $CHK/z-$ceventname.log
fname data    $CHK/z-$ceventname.data
echo on
input  $odir/$cnamecoll.optns
input  $odir/$cnamecoll.spherio.optns
runprogram
stopprogram
EOF
if ( -s $CHK/z-$ceventname.data ) then
  echo "###############################################################"
  echo "      output written to $CHK/z-$ceventname.data"
  echo "###############################################################"
else
  rm -f $CHK/z-$ceventname.data
endif
if ( -s $CHK/z-$ceventname.check ) then
else
  rm -f $CHK/z-$ceventname.check
endif
if ( -s $HTO/$ceventname.histo ) then
else
  rm -f $HTO/$ceventname.histo
endif
rm -f $CHK/z-$ceventname.log
rm -f $CHK/z-$ceventname.copy
if ( -s $CHK/z-$ceventname.see ) then
rm -f $CHK/z-$ceventname.see
endif
echo "###################################################################"
echo "#     This is the exit of" $ievent"-th event running on the node" $cfolderindex"        #"
echo "#            Bye-bye and happy debugging...                       #"
echo "###################################################################"
date

end

exit

